/**
 * PETALS: PETALS Services Platform
 * Copyright (C) 2005 EBM WebSourcing
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA.
 *
 * Initial developer(s): EBM WebSourcing
 */
package org.ow2.petals.ant.task;

import javax.management.MBeanServerConnection;

import org.apache.tools.ant.BuildException;
import org.ow2.petals.ant.AbstractJBIAntTask;
import org.ow2.petals.ant.JBIJMXConnectorUtil;

/**
 * Ant task : jbi-uninstall-shared-library. This task uninstall a previously
 * installed share library from the JBI environment.
 * 
 * @author ddesjardins chamerling - eBMWebsourcing
 */
public class UninstallSharedLibraryTask extends AbstractJBIAntTask {

    /**
     * Name of the shared library
     */
    private String name;

    /**
     * Creates a new instance of {@link UninstallSharedLibraryTask}
     * 
     */
    public UninstallSharedLibraryTask() {
        super();
    }

    /**
     * Execute the ant task
     * 
     * @throws BuildException
     */
    public void doTask() throws Exception {
        if (name == null) {
            throw new BuildException("Missing attribute 'name'");
        }

        MBeanServerConnection connection = connector.getMBeanServerConnection();

        Object[] objects = new Object[1];
        objects[0] = name;
        String[] strings = new String[1];
        strings[0] = "java.lang.String";
        Object result = connection.invoke(JBIJMXConnectorUtil
            .getInstallationServiceMBeanName(connection),
            "uninstallSharedLibrary", objects, strings);

        boolean uninstalled = ((Boolean) result).booleanValue();
        if (!uninstalled) {
            throw new BuildException("The shared library '" + name
                + "' has not been uninstalled");
        }
        log("The shared library '" + name + "' has been uninstalled");

    }

    /**
     * @param name
     *            the name to set
     */
    public void setName(String name) {
        this.name = name;
    }

}
